# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-10-23 14:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('flatpages', '0002_model_translation'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='flatpage',
            options={'ordering': ['url'], 'verbose_name': 'flat page', 'verbose_name_plural': 'flat pages'},
        ),
        migrations.AddField(
            model_name='flatpage',
            name='site',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='sites.Site', verbose_name='Site'),
        ),
    ]
