# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-01-16 15:26
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


def generate_operations():

    operations = []

    for code, name in settings.LANGUAGES:

        operations += [
            migrations.AddField(
                model_name='flatpage',
                name='title_%s' % code,
                field=models.CharField(max_length=200, null=True,
                                       verbose_name='title'),
            ),
            migrations.AddField(
                model_name='flatpage',
                name='content_%s' % code,
                field=models.TextField(blank=True, null=True,
                                       verbose_name='content'),
            ),
            migrations.AddField(
                model_name='flatpage',
                name='meta_k_%s' % code,
                field=models.CharField(max_length=200, null=True,
                                       verbose_name='keywords'),
            ),
            migrations.AddField(
                model_name='flatpage',
                name='meta_d_%s' % code,
                field=models.CharField(max_length=200, null=True,
                                       verbose_name='description'),
            )
        ]

    return operations


class Migration(migrations.Migration):

    dependencies = [
        ('flatpages', '0001_initial'),
    ]

    operations = generate_operations()
